@@ -629,6 +629,9 @@ game_about_callback (GtkWidget *widget, void *data)
 				 (const char **)documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
                                  pixbuf);
+	if (pixbuf != NULL)
+		gdk_pixbuf_unref (pixbuf);
+	
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
 	gtk_widget_show (about);
 
